/* See LICENSE file for copyright and license details. */

#include "global.h"

/* Constants */
#define TERMINAL "st"
#define TERMCLASS "St"

#define BROWSER "firefox-esr"

static const char wallpaper[] = "/home/suwako/.local/share/wallpapers/8ffe33a4a3459c39bcd0a11a528a3785-";
static const char ext[] = ".jpg";
extern char bgimg[100];

#if MYPC == DESKTOP
static const char resolution[] = "1080";
#elif MYPC == X200
static const char resolution[] = "900";
#elif MYPC == T400
static const char resolution[] = "800";
#elif MYPC == X250 || MYPC == S130
static const char resolution[] = "768";
#elif MYPC == T43
static const char resolution[] = "1050";
#elif MYPC == PINEPHONE
static const char resolution[] = "1280";
#endif

typedef enum {
  MODE_CENTER,
  MODE_COVER,
  MODE_TILE,
  MODE_FULL,
  /* MODE_EXTEND, */
  MODE_FILL
} BGMode;

/* appearance */
static unsigned int borderpx  = 3;         /* border pixel of windows */
static unsigned int snap      = 32;        /* snap pixel */
static unsigned int gappih    = 5;         /* horiz inner gap between windows */
static unsigned int gappiv    = 5;         /* vert inner gap between windows */
static unsigned int gappoh    = 5;         /* horiz outer gap between windows and screen edge */
static unsigned int gappov    = 5;         /* vert outer gap between windows and screen edge */
static unsigned int dpms      = -1;        /* 秒間。DPMSを無効にする場合：-1 */
static BGMode bgmode          = MODE_FILL; /* 背景モード */
static int swallowfloating    = 0;         /* 1 means swallow floating windows by default */
static int smartgaps          = 0;         /* 1 means no outer gap when there is only one window */
static int showbar            = 1;         /* 0 means no bar */
static int topbar             = 1;         /* 0 means bottom bar */
#if MYPC == DESKTOP || MYPC == T43
static char *fonts[]          = { "monospace:size=10", "NotoColorEmoji:pixelsize=10:antialias=true:autohint=true"  };
#else
static char *fonts[]          = { "monospace:size=12", "NotoColorEmoji:pixelsize=12:antialias=true:autohint=true"  };
#endif
static char normbgcolor[]           = "#120f12";
static char normbordercolor[]       = "#120f12";
static char normfgcolor[]           = "#fcfcfc";
static char selbgcolor[]            = "#ea81e8";//"#a347a3";
static char selbordercolor[]        = "#ea81e8";//"#a347a3";
static char selfgcolor[]            = "#232629";
static char *colors[][3] = {
  /*               fg           bg           border   */
  [SchemeNorm] = { normfgcolor, normbgcolor, normbordercolor },
  [SchemeSel]  = { selfgcolor,  selbgcolor,  selbordercolor  },
};

typedef struct {
  const char *name;
  const void *cmd;
} Sp;
const char *spcmd1[] = {TERMINAL, "-n", "spterm", "-g", "120x34", NULL };
const char *spcmd2[] = {TERMINAL, "-n", "spcalc", "-f", "monospace:size=16", "-g", "50x20", "-e", "bc", "-lq", NULL };
static Sp scratchpads[] = {
  /* name          cmd  */
  {"spterm",      spcmd1},
  {"spcalc",      spcmd2},
};

static const char *const autostart[] = {
#if MYOS == OPENBSD
  "uim", NULL,
#else
  "fcitx5", NULL,
#endif
  NULL /* terminate */
};

/* tagging */
static const char *tags[] = { "1", "2", "3", "4", "5", "6", "7", "8", "9" };

static const Rule rules[] = {
  /* xprop(1):
   *  WM_CLASS(STRING) = instance, class
   *  WM_NAME(STRING) = title
  */
  /* class    instance      title          tags mask    isfloating   isterminal  noswallow  monitor */
  { "Gimp",     NULL,       NULL,             1 << 8,       0,           0,         0,        -1 },
  { TERMCLASS,  NULL,       NULL,             0,            0,           1,         0,        -1 },
  { NULL,       NULL,       "Event Tester",   0,            0,           0,         1,        -1 },
  { TERMCLASS,      "floatterm", NULL,            0,       1,           1,         0,        -1 },
  { TERMCLASS,      "bg",        NULL,            1 << 7,       0,           1,         0,        -1 },
  { TERMCLASS,      "spterm",    NULL,            SPTAG(0),     1,           1,         0,        -1 },
  { TERMCLASS,      "spcalc",    NULL,            SPTAG(1),     1,           1,         0,        -1 },
};

/* layout(s) */
static float mfact     = 0.55; /* factor of master area size [0.05..0.95] */
static int nmaster     = 1;    /* number of clients in master area */
static int resizehints = 0;    /* 1 means respect size hints in tiled resizals */
static const int lockfullscreen = 1; /* 1 will force focus on the fullscreen window */
#define FORCE_VSPLIT 1  /* nrowgrid layout: force two clients to always split vertically */
#include "vanitygaps.c"
static const Layout layouts[] = {
  /* symbol     arrange function */
  { "[]=",  tile },     /* Default: Master on left, slaves on right */
  { "TTT",  bstack },   /* Master on top, slaves on bottom */

  { "[@]",  spiral },   /* Fibonacci spiral */
  { "[\\]", dwindle },    /* Decreasing in size right and leftward */

  { "[D]",  deck },     /* Master on left, slaves in monocle-like mode on right */
  { "[M]",  monocle },    /* All windows on top of eachother */

  { "|M|",  centeredmaster },   /* Master in middle, slaves on sides */
  { ">M>",  centeredfloatingmaster }, /* Same but master floats */

  { "><>",  NULL },     /* no layout function means floating behavior */
  { NULL,   NULL },
};

/* key definitions */
#if MYPC == T43
#define MODKEY XK_Eisu_toggle
#else
#define MODKEY Mod4Mask
#endif
#define TAGKEYS(KEY,TAG) \
  { MODKEY,                       KEY,      view,           {.ui = 1 << TAG} }, \
  { MODKEY|ControlMask,           KEY,      toggleview,     {.ui = 1 << TAG} }, \
  { MODKEY|ShiftMask,             KEY,      tag,            {.ui = 1 << TAG} }, \
  { MODKEY|ControlMask|ShiftMask, KEY,      toggletag,      {.ui = 1 << TAG} },
#define STACKKEYS(MOD,ACTION) \
  { MOD,  XK_j, ACTION##stack,  {.i = INC(+1) } }, \
  { MOD,  XK_k, ACTION##stack,  {.i = INC(-1) } }, \
  { MOD,  XK_v,   ACTION##stack,  {.i = 0 } }, \
  /* { MOD, XK_grave, ACTION##stack, {.i = PREVSEL } }, \ */
  /* { MOD, XK_a,     ACTION##stack, {.i = 1 } }, \ */
  /* { MOD, XK_z,     ACTION##stack, {.i = 2 } }, \ */
  /* { MOD, XK_x,     ACTION##stack, {.i = -1 } }, */

/* helper for spawning shell commands in the pre dwm-5.0 fashion */
#define SHCMD(cmd) { .v = (const char*[]){ "/bin/sh", "-c", cmd, NULL } }

/* commands */
#if MYPC == DESKTOP || MYPC == T43
static const char *dmenucmd[] = { "dmenu_run", "-fn", "monospace:size=10", "-nb", normbgcolor, "-nf", normfgcolor, "-sb", selbgcolor, "-sf", selfgcolor, NULL };
#else
static const char *dmenucmd[] = { "dmenu_run", "-fn", "monospace:size=8", "-nb", normbgcolor, "-nf", normfgcolor, "-sb", selbgcolor, "-sf", selfgcolor, NULL };
#endif
static const char *termcmd[]  = { TERMINAL, NULL };

/*
 * Xresources preferences to load at startup
 */
ResourcePref resources[] = {
  { "color0",   STRING, &normbordercolor },
  { "color8",   STRING, &selbordercolor },
  { "color0",   STRING, &normbgcolor },
  { "color4",   STRING, &normfgcolor },
  { "color0",   STRING, &selfgcolor },
  { "color4",   STRING, &selbgcolor },
  { "borderpx",   INTEGER, &borderpx },
  { "snap",   INTEGER, &snap },
  { "showbar",    INTEGER, &showbar },
  { "topbar",   INTEGER, &topbar },
  { "nmaster",    INTEGER, &nmaster },
  { "resizehints",  INTEGER, &resizehints },
  { "mfact",    FLOAT,  &mfact },
  { "gappih",   INTEGER, &gappih },
  { "gappiv",   INTEGER, &gappiv },
  { "gappoh",   INTEGER, &gappoh },
  { "gappov",   INTEGER, &gappov },
  { "swallowfloating",  INTEGER, &swallowfloating },
  { "smartgaps",    INTEGER, &smartgaps },
};

#include <X11/XF86keysym.h>
#include "shiftview.c"

static const Key keys[] = {
  /* modifier                     key        function        argument */
  STACKKEYS(MODKEY,                          focus)
  STACKKEYS(MODKEY|ShiftMask,                push)
  /* { MODKEY|ShiftMask,    XK_Escape,  spawn,  SHCMD("") }, */
  { MODKEY,     XK_Zenkaku_Hankaku, spawn,  {.v = dmenucmd } },
  /* { MODKEY|ShiftMask,    XK_Zenkaku_Hankaku, togglescratch,  SHCMD("") }, */
  TAGKEYS(      XK_1,   0)
  TAGKEYS(      XK_2,   1)
  TAGKEYS(      XK_3,   2)
  TAGKEYS(      XK_4,   3)
  TAGKEYS(      XK_5,   4)
  TAGKEYS(      XK_6,   5)
  TAGKEYS(      XK_7,   6)
  TAGKEYS(      XK_8,   7)
  TAGKEYS(      XK_9,   8)
  { MODKEY,     XK_0,   view,   {.ui = ~0 } },
  { MODKEY|ShiftMask,   XK_0,   tag,    {.ui = ~0 } },
#if MYOS == ALPINE || MYOS == ARTIX || MYOS == CRUX || MYOS == POSTMARKETOS || MYOS == VOID
  #if MYMX == ALSA
  { MODKEY,     XK_minus, spawn,    SHCMD("amixer sset Master 5%-; kill -44 $(pidof dwmblocks)") },
  { MODKEY|ShiftMask,   XK_minus, spawn,    SHCMD("amixer sset Master 15%-; kill -44 $(pidof dwmblocks)") },
  { MODKEY,     XK_asciicircum, spawn,    SHCMD("amixer sset Master 5%+; kill -44 $(pidof dwmblocks)") },
  { MODKEY|ShiftMask,   XK_asciicircum, spawn,    SHCMD("amixer sset Master 15%+; kill -44 $(pidof dwmblocks)") },
  #elif MYMX == PULSEAUDIO
  { MODKEY,     XK_minus, spawn,    SHCMD("pamixer --allow-boost -d 5; kill -44 $(pidof dwmblocks)") },
  { MODKEY|ShiftMask,   XK_minus, spawn,    SHCMD("pamixer --allow-boost -d 15; kill -44 $(pidof dwmblocks)") },
  { MODKEY,     XK_asciicircum, spawn,    SHCMD("pamixer --allow-boost -i 5; kill -44 $(pidof dwmblocks)") },
  { MODKEY|ShiftMask,   XK_asciicircum, spawn,    SHCMD("pamixer --allow-boost -i 15; kill -44 $(pidof dwmblocks)") },
  #elif MYMX == PIPEWIRE
  { MODKEY,     XK_minus, spawn,    SHCMD("wpctl set-volume @DEFAULT_AUDIO_SINK@ 5%-; kill -44 $(pidof dwmblocks)") },
  { MODKEY|ShiftMask,   XK_minus, spawn,    SHCMD("wpctl set-volume @DEFAULT_AUDIO_SINK@ 15%-; kill -44 $(pidof dwmblocks)") },
  { MODKEY,     XK_asciicircum, spawn,    SHCMD("wpctl set-volume @DEFAULT_AUDIO_SINK@ 5%+; kill -44 $(pidof dwmblocks)") },
  { MODKEY|ShiftMask,   XK_asciicircum, spawn,    SHCMD("wpctl set-volume @DEFAULT_AUDIO_SINK@ 15%+; kill -44 $(pidof dwmblocks)") },
  #endif // MYMX
#elif MYOS == OPENBSD || MYOS == NETBSD
  { MODKEY,     XK_minus, spawn,    SHCMD("doas mixerctl outputs.master=-5%; kill -44 $(pidof dwmblocks)") },
  { MODKEY|ShiftMask,   XK_minus, spawn,    SHCMD("doas mixerctl outputs.master=-15%; kill -44 $(pidof dwmblocks)") },
  { MODKEY,     XK_asciicircum, spawn,    SHCMD("doas mixerctl outputs.master=+5%; kill -44 $(pidof dwmblocks)") },
  { MODKEY|ShiftMask,   XK_asciicircum, spawn,    SHCMD("doas mixerctl outputs.master=+15%; kill -44 $(pidof dwmblocks)") },
#elif MYOS == FREEBSD
  { MODKEY,     XK_minus, spawn,    SHCMD("mixer vol -5%; kill -44 $(pidof dwmblocks)") },
  { MODKEY|ShiftMask,   XK_minus, spawn,    SHCMD("mixer vol -15%; kill -44 $(pidof dwmblocks)") },
  { MODKEY,     XK_asciicircum, spawn,    SHCMD("mixer vol +5%; kill -44 $(pidof dwmblocks)") },
  { MODKEY|ShiftMask,   XK_asciicircum, spawn,    SHCMD("mixer vol +15%; kill -44 $(pidof dwmblocks)") },
#endif // MYOS
  { MODKEY,     XK_BackSpace, spawn,    {.v = (const char*[]){ "sysact", NULL } } },
  { MODKEY|ShiftMask,   XK_BackSpace, spawn,    {.v = (const char*[]){ "sysact", NULL } } },

  { MODKEY,     XK_Tab,   view,   {0} },
  /* { MODKEY|ShiftMask,    XK_Tab,   spawn,    SHCMD("") }, */
  { MODKEY,     XK_q,   killclient, {0} },
  { MODKEY|ShiftMask,   XK_q,   spawn,    {.v = (const char*[]){ "sysact", NULL } } },
  { MODKEY,     XK_w,   spawn,    {.v = (const char*[]){ BROWSER, NULL } } },
  { MODKEY|ShiftMask,   XK_w,   spawn,    SHCMD(TERMINAL " -e byobu new-session -d -s browser 'proxychains -q lynx -lss ~/.config/lynx/lynx.lss https://technicalsuwako.moe' && byobu attach-session -t browser") },
  { MODKEY,     XK_e,   spawn,    {.v = (const char*[]){ TERMINAL, "-e", "neomutt" } } },
  { MODKEY|ShiftMask,   XK_e,   spawn,    {.v = (const char*[]){ TERMINAL, "-e", "byobu" } } },
  { MODKEY,     XK_r,   spawn,    {.v = (const char*[]){ TERMINAL, "-e", "lf", NULL } } },
  { MODKEY|ShiftMask,   XK_r,   spawn,    {.v = (const char*[]){ TERMINAL, "-e", "btop", NULL } } },
  { MODKEY,     XK_t,   setlayout,  {.v = &layouts[0]} }, /* tile */
  { MODKEY|ShiftMask,   XK_t,   setlayout,  {.v = &layouts[1]} }, /* bstack */
  { MODKEY,     XK_y,   setlayout,  {.v = &layouts[2]} }, /* spiral */
  { MODKEY|ShiftMask,   XK_y,   setlayout,  {.v = &layouts[3]} }, /* dwindle */
  { MODKEY,     XK_u,   setlayout,  {.v = &layouts[4]} }, /* deck */
  { MODKEY|ShiftMask,   XK_u,   setlayout,  {.v = &layouts[5]} }, /* monocle */
  { MODKEY,     XK_i,   setlayout,  {.v = &layouts[6]} }, /* centeredmaster */
  { MODKEY|ShiftMask,   XK_i,   setlayout,  {.v = &layouts[7]} }, /* centeredfloatingmaster */
  { MODKEY,     XK_o,   incnmaster,     {.i = +1 } },
  { MODKEY|ShiftMask,   XK_o,   incnmaster,     {.i = -1 } },
  { MODKEY,     XK_p,     spawn,    {.v = (const char*[]){ "mpc", "toggle", NULL } } },
  { MODKEY|ShiftMask,   XK_p,     spawn,    SHCMD("mpc pause; pauseallmpv") },
  { MODKEY,     XK_at,    spawn,    {.v = (const char*[]){ "mpc", "seek", "-10", NULL } } },
  { MODKEY|ShiftMask,   XK_at,    spawn,    {.v = (const char*[]){ "mpc", "seek", "-60", NULL } } },
  { MODKEY,     XK_bracketleft, spawn,    {.v = (const char*[]){ "mpc", "seek", "+10", NULL } } },
  { MODKEY|ShiftMask,   XK_bracketleft, spawn,    {.v = (const char*[]){ "mpc", "seek", "+60", NULL } } },

#if MYPC != T43
  { MODKEY,     XK_Eisu_toggle,   spawn,     {.v = (const char*[]){ "rofi", "-show", "calc", NULL } } },
#endif
  { MODKEY,     XK_a,   togglegaps, {0} },
  { MODKEY|ShiftMask,   XK_a,   defaultgaps,  {0} },
  { MODKEY,     XK_s,   togglesticky, {0} },
  { MODKEY|ShiftMask,   XK_s,   spawn,    {.v = (const char*[]){ "doas", "slock", NULL } } },
  { MODKEY,     XK_d,   spawn,     {.v = (const char*[]){ "rofi", "-show", "drun", NULL } } },
  { MODKEY|ShiftMask,   XK_d,   spawn,    {.v = (const char*[]){ "rofi-pass", "--root", "/home/suwako/.local/share/sp", NULL } } },
  { MODKEY,     XK_f,   togglefullscr,  {0} },
  { MODKEY|ShiftMask,   XK_f,   setlayout,  {.v = &layouts[8]} },
  { MODKEY,     XK_g,   shiftview,  { .i = -1 } },
  { MODKEY|ShiftMask,   XK_g,   shifttag, { .i = -1 } },
  { MODKEY,     XK_h,   setmfact, {.f = -0.05} },
  /* J and K are automatically bound above in STACKEYS */
  { MODKEY,     XK_l,   setmfact,       {.f = +0.05} },
  { MODKEY,     XK_semicolon, shiftview,  { .i = 1 } },
  { MODKEY|ShiftMask,   XK_semicolon, shifttag, { .i = 1 } },
  { MODKEY,     XK_colon, togglescratch,  {.ui = 1} },
  { MODKEY|ShiftMask,   XK_colon, togglesmartgaps,  {0} },
  { MODKEY,     XK_Return,  spawn,    {.v = termcmd } },
  { MODKEY|ShiftMask,   XK_Return,  togglescratch,  {.ui = 0} },

  { MODKEY,     XK_z,   spawn,    {.v = (const char*[]){ "rofi-youtube", "-i", NULL } } },
  { MODKEY|ShiftMask,   XK_z,   spawn,    {.v = (const char*[]){ "rofi-youtube", "-s", NULL } } },
  { MODKEY,     XK_x,   incrgaps, {.i = -3 } },
  { MODKEY|ShiftMask,   XK_x,   incrgaps, {.i = +3 } },
  { MODKEY,     XK_c,   spawn,    {.v = (const char*[]){ TERMINAL, "-e", "profanity", NULL } } },
  { MODKEY|ShiftMask,   XK_c,   spawn,    {.v = (const char*[]){ TERMINAL, "-e", "tut", NULL } } },
  /* V is automatically bound above in STACKKEYS */
  { MODKEY,     XK_b,   togglebar,  {0} },
  { MODKEY|ShiftMask,   XK_b,   spawn,    {.v = (const char*[]){ TERMINAL, "-e", "weechat", NULL } } },
  { MODKEY,     XK_n,   spawn,    {.v = (const char*[]){ TERMINAL, "-e", "nvim", NULL } } },
  { MODKEY|ShiftMask,   XK_n,   spawn,    SHCMD(TERMINAL " -e proxychains -q newsboat ; pkill -RTMIN+6 dwmblocks") },
  { MODKEY,     XK_m,   spawn,    {.v = (const char*[]){ TERMINAL, "-e", "ncmpcpp", NULL } } },
#if MYOS == ALPINE || MYOS == ARTIX || MYOS == CRUX || MYOS == POSTMARKETOS || MYOS == VOID
  #if MYMX == ALSA
  { MODKEY|ShiftMask,   XK_m,   spawn,    SHCMD("amixer set Master toggle; kill -44 $(pidof dwmblocks)") },
  #elif MYMX == PULSEAUDIO
  { MODKEY|ShiftMask,   XK_m,   spawn,    SHCMD("pamixer -t; kill -44 $(pidof dwmblocks)") },
  #elif MYMX == PIPEWIRE
  { MODKEY|ShiftMask,   XK_m,   spawn,    SHCMD("wpctl set-mute @DEFAULT_AUDIO_SINK@ toggle; kill -44 $(pidof dwmblocks)") },
  #endif // MYMX
#elif MYOS == OPENBSD || MYOS == NETBSD
  { MODKEY|ShiftMask,   XK_m,   spawn,    SHCMD("doas mixerctl outputs.master.mute=toggle; kill -44 $(pidof dwmblocks)") },
#elif MYOS == FREEBSD
  { MODKEY|ShiftMask,   XK_m,   spawn,    SHCMD("mixer vol 0:0; kill -44 $(pidof dwmblocks)") },
#endif // MYMX
  { MODKEY,     XK_comma, spawn,    {.v = (const char*[]){ "mpc", "prev", NULL } } },
  { MODKEY|ShiftMask,   XK_comma, spawn,    {.v = (const char*[]){ "mpc", "seek", "0%", NULL } } },
  { MODKEY,     XK_period,  spawn,    {.v = (const char*[]){ "mpc", "next", NULL } } },
  { MODKEY|ShiftMask,   XK_period,  spawn,    {.v = (const char*[]){ "mpc", "repeat", NULL } } },
  { MODKEY,     XK_backslash,   view,   {0} },
  /* { MODKEY|ShiftMask,    XK_backslash,   spawn,    SHCMD("") }, */

  { MODKEY,     XK_Left,  focusmon, {.i = -1 } },
  { MODKEY|ShiftMask,   XK_Left,  tagmon,   {.i = -1 } },
  { MODKEY,     XK_Right, focusmon, {.i = +1 } },
  { MODKEY|ShiftMask,   XK_Right, tagmon,   {.i = +1 } },

  { MODKEY,     XK_Page_Up, shiftview,  { .i = -1 } },
  { MODKEY|ShiftMask,   XK_Page_Up, shifttag, { .i = -1 } },
  { MODKEY,     XK_Page_Down, shiftview,  { .i = +1 } },
  { MODKEY|ShiftMask,   XK_Page_Down, shifttag, { .i = +1 } },
  /* { MODKEY,      XK_Insert,  spawn,    SHCMD("") }, */

  /* { MODKEY,      XK_F1,    spawn,    SHCMD("") }, */
  /* { MODKEY,      XK_F2,    spawn,    SHCMD("") }, */
  /* { MODKEY,      XK_F3,    spawn,    SHCMD("") }, */
  /* { MODKEY,      XK_F4,    spawn,    SHCMD("") }, */
  { MODKEY,     XK_F5,    xrdb,   {.v = NULL } },
  /* { MODKEY,      XK_F6,    spawn,    SHCMD("") }, */
  /* { MODKEY,      XK_F7,    spawn,    SHCMD("") }, */
  /* { MODKEY,      XK_F8,    spawn,    SHCMD("") }, */
  /* { MODKEY,      XK_F9,    spawn,    SHCMD("") }, */
  /* { MODKEY,      XK_F10,   spawn,    SHCMD("") }, */
  /* { MODKEY,      XK_F11,   spawn,    SHCMD("") }, */
  /* { MODKEY,      XK_F12,   spawn,    SHCMD("") }, */
  { MODKEY,     XK_space, zoom,   {0} },
  { MODKEY|ShiftMask,   XK_space, togglefloating, {0} },

  /* { 0,       XK_Print, spawn,    SHCMD("") }, */
  /* { ShiftMask,     XK_Print, spawn,    SHCMD("") }, */
  /* { MODKEY,      XK_Print, spawn,    SHCMD("") }, */
  /* { MODKEY|ShiftMask,    XK_Print, spawn,    SHCMD("") }, */
  /* { MODKEY,      XK_Delete,  spawn,    SHCMD("") }, */
  /* { MODKEY,      XK_Scroll_Lock, spawn,    SHCMD("") }, */

  /* { 0, XF86XK_AudioMute,   spawn,    SHCMD("") }, */
  /* { 0, XF86XK_AudioRaiseVolume,  spawn,    SHCMD("") }, */
  /* { 0, XF86XK_AudioLowerVolume,  spawn,    SHCMD("") }, */
  /* { 0, XF86XK_AudioPrev,   spawn,    SHCMD("") }, */
  /* { 0, XF86XK_AudioNext,   spawn,    SHCMD("") }, */
  /* { 0, XF86XK_AudioPause,    spawn,    SHCMD("") }, */
  /* { 0, XF86XK_AudioPlay,   spawn,    SHCMD("") }, */
  /* { 0, XF86XK_AudioStop,   spawn,    SHCMD("") }, */
  /* { 0, XF86XK_AudioRewind, spawn,    SHCMD("") }, */
  /* { 0, XF86XK_AudioForward,  spawn,    SHCMD("") }, */
  /* { 0, XF86XK_AudioMedia,    spawn,    SHCMD("") }, */
  /* { 0, XF86XK_AudioMicMute,  spawn,    SHCMD("") }, */
  /* { 0, XF86XK_PowerOff,    spawn,    {.v = (const char*[]){ "sysact", NULL } } }, */
  /* { 0, XF86XK_Calculator,    spawn,    SHCMD("") }, */
  /* { 0, XF86XK_Sleep,   spawn,    SHCMD("") }, */
  /* { 0, XF86XK_WWW,   spawn,    SHCMD("") }, */
  /* { 0, XF86XK_DOS,   spawn,    SHCMD("") }, */
  /* { 0, XF86XK_ScreenSaver, spawn,    SHCMD("") }, */
  /* { 0, XF86XK_TaskPane,    spawn,    SHCMD("") }, */
  /* { 0, XF86XK_Mail,    spawn,    SHCMD("") }, */
  /* { 0, XF86XK_MyComputer,    spawn,    SHCMD("") }, */
  /* { 0, XF86XK_Battery,   spawn,    SHCMD("") }, */
  /* { 0, XF86XK_Launch1,   spawn,    SHCMD("") }, */
  /* { 0, XF86XK_TouchpadToggle,  spawn,    SHCMD("") }, */
  /* { 0, XF86XK_TouchpadOff, spawn,    SHCMD("") }, */
  /* { 0, XF86XK_TouchpadOn,    spawn,    SHCMD("") }, */
  /* { 0, XF86XK_MonBrightnessUp, spawn,    SHCMD("") }, */
  /* { 0, XF86XK_MonBrightnessDown, spawn,    SHCMD("") }, */

  /* { MODKEY|Mod4Mask,              XK_h,      incrgaps,       {.i = +1 } }, */
  /* { MODKEY|Mod4Mask,              XK_l,      incrgaps,       {.i = -1 } }, */
  /* { MODKEY|Mod4Mask|ShiftMask,    XK_h,      incrogaps,      {.i = +1 } }, */
  /* { MODKEY|Mod4Mask|ShiftMask,    XK_l,      incrogaps,      {.i = -1 } }, */
  /* { MODKEY|Mod4Mask|ControlMask,  XK_h,      incrigaps,      {.i = +1 } }, */
  /* { MODKEY|Mod4Mask|ControlMask,  XK_l,      incrigaps,      {.i = -1 } }, */
  /* { MODKEY|Mod4Mask|ShiftMask,    XK_0,      defaultgaps,    {0} }, */
  /* { MODKEY,                       XK_y,      incrihgaps,     {.i = +1 } }, */
  /* { MODKEY,                       XK_o,      incrihgaps,     {.i = -1 } }, */
  /* { MODKEY|ControlMask,           XK_y,      incrivgaps,     {.i = +1 } }, */
  /* { MODKEY|ControlMask,           XK_o,      incrivgaps,     {.i = -1 } }, */
  /* { MODKEY|Mod4Mask,              XK_y,      incrohgaps,     {.i = +1 } }, */
  /* { MODKEY|Mod4Mask,              XK_o,      incrohgaps,     {.i = -1 } }, */
  /* { MODKEY|ShiftMask,             XK_y,      incrovgaps,     {.i = +1 } }, */
  /* { MODKEY|ShiftMask,             XK_o,      incrovgaps,     {.i = -1 } }, */

};

/* button definitions */
/* click can be ClkTagBar, ClkLtSymbol, ClkStatusText, ClkWinTitle, ClkClientWin, or ClkRootWin */
static const Button buttons[] = {
  /* click                event mask      button          function        argument */
#ifndef __OpenBSD__
  { ClkWinTitle,          0,              Button2,        zoom,           {0} },
  { ClkStatusText,        0,              Button1,        sigdwmblocks,   {.i = 1} },
  { ClkStatusText,        0,              Button2,        sigdwmblocks,   {.i = 2} },
  { ClkStatusText,        0,              Button3,        sigdwmblocks,   {.i = 3} },
  { ClkStatusText,        0,              Button4,        sigdwmblocks,   {.i = 4} },
  { ClkStatusText,        0,              Button5,        sigdwmblocks,   {.i = 5} },
  { ClkStatusText,        ShiftMask,      Button1,        sigdwmblocks,   {.i = 6} },
#endif
  { ClkStatusText,        ShiftMask,      Button3,        spawn,          SHCMD(TERMINAL " -e nvim ~/.local/src/dwmblocks/config.h") },
  { ClkClientWin,         MODKEY,         Button1,        movemouse,      {0} },
  { ClkClientWin,         MODKEY,         Button2,        defaultgaps,  {0} },
  { ClkClientWin,         MODKEY,         Button3,        resizemouse,    {0} },
  { ClkClientWin,   MODKEY,   Button4,  incrgaps, {.i = +1} },
  { ClkClientWin,   MODKEY,   Button5,  incrgaps, {.i = -1} },
  { ClkTagBar,            0,              Button1,        view,           {0} },
  { ClkTagBar,            0,              Button3,        toggleview,     {0} },
  { ClkTagBar,            MODKEY,         Button1,        tag,            {0} },
  { ClkTagBar,            MODKEY,         Button3,        toggletag,      {0} },
  { ClkTagBar,    0,    Button4,  shiftview,  {.i = -1} },
  { ClkTagBar,    0,    Button5,  shiftview,  {.i = 1} },
  { ClkRootWin,   0,    Button2,  togglebar,  {0} },
};
